@@ -18,7 +18,7 @@ extends 'Lemonldap::NG::Manager::Lib';
 
 has conf => ( is => 'rw', isa => 'HashRef', default => sub { {} } );
 
-our $VERSION = '1.9.8';
+our $VERSION = '1.9.9';
 
 #############################
 # I. INITIALIZATION METHODS #
@@ -122,6 +122,11 @@ sub sessions {
           : ( $s => $params->{$_} );
     } keys %$params;
     $filters{_session_kind} = $type;
+    push @fields, keys(%filters);
+    {
+        my %seen;
+        @fields = grep { !$seen{$_}++ } @fields;
+    }
 
     # Check if a '*' is required
     my $function = 'searchOn';
@@ -151,6 +156,7 @@ sub sessions {
 
     delete $filters{$firstFilter};
     foreach my $k ( keys %filters ) {
+        $filters{$k} =~ s/\./\\./g;
         $filters{$k} =~ s/\*/\.\*/g;
         foreach my $session ( keys %$res ) {
             if ( $res->{$session}->{$k} ) {
